@@ -16,11 +16,6 @@
 #define GEN7_MEDIA_STATE_POINTERS		GEN7_3D(2, 0, 0)
 #define GEN7_MEDIA_OBJECT			GEN7_3D(2, 1, 0)
 
-#define GEN7_3DSTATE_BINDING_TABLE_POINTERS	GEN7_3D(3, 0, 1)
-# define GEN7_3DSTATE_BINDING_TABLE_MODIFY_PS  (1 << 12)/* for GEN7 */
-# define GEN7_3DSTATE_BINDING_TABLE_MODIFY_GS  (1 << 9) /* for GEN7 */
-# define GEN7_3DSTATE_BINDING_TABLE_MODIFY_VS  (1 << 8) /* for GEN7 */
-
 #define GEN7_3DSTATE_VERTEX_BUFFERS		GEN7_3D(3, 0, 8)
 #define GEN7_3DSTATE_VERTEX_ELEMENTS		GEN7_3D(3, 0, 9)
 #define GEN7_3DSTATE_INDEX_BUFFER		GEN7_3D(3, 0, 0xa)
@@ -86,24 +81,46 @@
 # define GEN7_3DSTATE_SF_TRIFAN_PROVOKE_SHIFT		25
 
 #define GEN7_3DSTATE_WM				GEN7_3D(3, 0, 0x14)
+/* DW1 */
+# define GEN7_WM_STATISTICS_ENABLE                              (1 << 31)
+# define GEN7_WM_DEPTH_CLEAR                                    (1 << 30)
+# define GEN7_WM_DISPATCH_ENABLE                                (1 << 29)
+# define GEN7_WM_DEPTH_RESOLVE                                  (1 << 28)
+# define GEN7_WM_HIERARCHICAL_DEPTH_RESOLVE                     (1 << 27)
+# define GEN7_WM_KILL_ENABLE                                    (1 << 25)
+# define GEN7_WM_PSCDEPTH_OFF                                   (0 << 23)
+# define GEN7_WM_PSCDEPTH_ON                                    (1 << 23)
+# define GEN7_WM_PSCDEPTH_ON_GE                                 (2 << 23)
+# define GEN7_WM_PSCDEPTH_ON_LE                                 (3 << 23)
+# define GEN7_WM_USES_SOURCE_DEPTH                              (1 << 20)
+# define GEN7_WM_USES_SOURCE_W                                  (1 << 19)
+# define GEN7_WM_POSITION_ZW_PIXEL                              (0 << 17)
+# define GEN7_WM_POSITION_ZW_CENTROID                           (2 << 17)
+# define GEN7_WM_POSITION_ZW_SAMPLE                             (3 << 17)
+# define GEN7_WM_NONPERSPECTIVE_SAMPLE_BARYCENTRIC              (1 << 16)
+# define GEN7_WM_NONPERSPECTIVE_CENTROID_BARYCENTRIC            (1 << 15)
+# define GEN7_WM_NONPERSPECTIVE_PIXEL_BARYCENTRIC               (1 << 14)
+# define GEN7_WM_PERSPECTIVE_SAMPLE_BARYCENTRIC                 (1 << 13)
+# define GEN7_WM_PERSPECTIVE_CENTROID_BARYCENTRIC               (1 << 12)
+# define GEN7_WM_PERSPECTIVE_PIXEL_BARYCENTRIC                  (1 << 11)
+# define GEN7_WM_USES_INPUT_COVERAGE_MASK                       (1 << 10)
+# define GEN7_WM_LINE_END_CAP_AA_WIDTH_0_5                      (0 << 8)
+# define GEN7_WM_LINE_END_CAP_AA_WIDTH_1_0                      (1 << 8)
+# define GEN7_WM_LINE_END_CAP_AA_WIDTH_2_0                      (2 << 8)
+# define GEN7_WM_LINE_END_CAP_AA_WIDTH_4_0                      (3 << 8)
+# define GEN7_WM_LINE_AA_WIDTH_0_5                              (0 << 6)
+# define GEN7_WM_LINE_AA_WIDTH_1_0                              (1 << 6)
+# define GEN7_WM_LINE_AA_WIDTH_2_0                              (2 << 6)
+# define GEN7_WM_LINE_AA_WIDTH_4_0                              (3 << 6)
+# define GEN7_WM_POLYGON_STIPPLE_ENABLE                         (1 << 4)
+# define GEN7_WM_LINE_STIPPLE_ENABLE                            (1 << 3)
+# define GEN7_WM_POINT_RASTRULE_UPPER_RIGHT                     (1 << 2)
+# define GEN7_WM_MSRAST_OFF_PIXEL                               (0 << 0)
+# define GEN7_WM_MSRAST_OFF_PATTERN                             (1 << 0)
+# define GEN7_WM_MSRAST_ON_PIXEL                                (2 << 0)
+# define GEN7_WM_MSRAST_ON_PATTERN                              (3 << 0)
 /* DW2 */
-# define GEN7_3DSTATE_WM_SAMPLER_COUNT_SHIFT			27
-# define GEN7_3DSTATE_WM_BINDING_TABLE_ENTRY_COUNT_SHIFT	18
-/* DW4 */
-# define GEN7_3DSTATE_WM_DISPATCH_START_GRF_0_SHIFT		16
-/* DW5 */
-# define GEN7_3DSTATE_WM_MAX_THREADS_SHIFT			25
-# define GEN7_3DSTATE_WM_DISPATCH_ENABLE			(1 << 19)
-# define GEN7_3DSTATE_WM_16_DISPATCH_ENABLE			(1 << 1)
-# define GEN7_3DSTATE_WM_8_DISPATCH_ENABLE			(1 << 0)
-/* DW6 */
-# define GEN7_3DSTATE_WM_NUM_SF_OUTPUTS_SHIFT			20
-# define GEN7_3DSTATE_WM_NONPERSPECTIVE_SAMPLE_BARYCENTRIC	(1 << 15)
-# define GEN7_3DSTATE_WM_NONPERSPECTIVE_CENTROID_BARYCENTRIC	(1 << 14)
-# define GEN7_3DSTATE_WM_NONPERSPECTIVE_PIXEL_BARYCENTRIC	(1 << 13)
-# define GEN7_3DSTATE_WM_PERSPECTIVE_SAMPLE_BARYCENTRIC		(1 << 12)
-# define GEN7_3DSTATE_WM_PERSPECTIVE_CENTROID_BARYCENTRIC	(1 << 11)
-# define GEN7_3DSTATE_WM_PERSPECTIVE_PIXEL_BARYCENTRIC		(1 << 10)
+# define GEN7_WM_MSDISPMODE_PERPIXEL                            (1 << 31)
 
 
 #define GEN7_3DSTATE_CONSTANT_VS		GEN7_3D(3, 0, 0x15)
@@ -127,6 +144,8 @@
 #define BASE_ADDRESS_MODIFY		(1 << 0)
 
 /* for GEN7_PIPE_CONTROL */
+#define GEN7_PIPE_CONTROL			GEN7_3D(3, 2, 0)
+#define GEN7_PIPE_CONTROL_CS_STALL      (1 << 20)
 #define GEN7_PIPE_CONTROL_NOWRITE       (0 << 14)
 #define GEN7_PIPE_CONTROL_WRITE_QWORD   (1 << 14)
 #define GEN7_PIPE_CONTROL_WRITE_DEPTH   (2 << 14)
@@ -138,6 +157,7 @@
 #define GEN7_PIPE_CONTROL_NOTIFY_ENABLE (1 << 8)
 #define GEN7_PIPE_CONTROL_GLOBAL_GTT    (1 << 2)
 #define GEN7_PIPE_CONTROL_LOCAL_PGTT    (0 << 2)
+#define GEN7_PIPE_CONTROL_STALL_AT_SCOREBOARD   (1 << 1)
 #define GEN7_PIPE_CONTROL_DEPTH_CACHE_FLUSH	(1 << 0)
 
 /* VERTEX_BUFFER_STATE Structure */
@@ -161,8 +181,6 @@
 /* 3DPRIMITIVE bits */
 #define GEN7_3DPRIMITIVE_VERTEX_SEQUENTIAL (0 << 15)
 #define GEN7_3DPRIMITIVE_VERTEX_RANDOM	  (1 << 15)
-/* Primitive types are in gen7_defines.h */
-#define GEN7_3DPRIMITIVE_TOPOLOGY_SHIFT	  10
 
 #define GEN7_SVG_CTL		       0x7400
 
@@ -173,11 +191,6 @@
 #define GEN7_SVG_CTL_IO_AUB	       (4 << 8)
 #define GEN7_SVG_CTL_SIP		       (5 << 8)
 
-#define GEN7_SVG_RDATA		       0x7404
-#define GEN7_SVG_WORK_CTL	       0x7408
-
-#define GEN7_VF_CTL		       0x7500
-
 #define GEN7_VF_CTL_SNAPSHOT_COMPLETE		   (1 << 31)
 #define GEN7_VF_CTL_SNAPSHOT_MUX_SELECT_THREADID	   (0 << 8)
 #define GEN7_VF_CTL_SNAPSHOT_MUX_SELECT_VF_DEBUG	   (1 << 8)
@@ -186,7 +199,7 @@
 #define GEN7_VF_CTL_SKIP_INITIAL_PRIMITIVES	   (1 << 3)
 #define GEN7_VF_CTL_MAX_PRIMITIVES_LIMIT_ENABLE	   (1 << 2)
 #define GEN7_VF_CTL_VERTEX_RANGE_LIMIT_ENABLE	   (1 << 1)
-#define GEN7_VF_CTL_SNAPSHOT_ENABLE	     	   (1 << 0)
+#define GEN7_VF_CTL_SNAPSHOT_ENABLE		   (1 << 0)
 
 #define GEN7_VF_STRG_VAL		       0x7504
 #define GEN7_VF_STR_VL_OVR	       0x7508
@@ -249,7 +262,7 @@
 #define GEN7_TS_CTL_SNAPSHOT_MESSAGE_ERROR	   (0 << 8)
 #define GEN7_TS_CTL_SNAPSHOT_INTERFACE_DESCRIPTOR   (3 << 8)
 #define GEN7_TS_CTL_SNAPSHOT_ALL_CHILD_THREADS	   (1 << 2)
-#define GEN7_TS_CTL_SNAPSHOT_ALL_ROOT_THREADS  	   (1 << 1)
+#define GEN7_TS_CTL_SNAPSHOT_ALL_ROOT_THREADS	   (1 << 1)
 #define GEN7_TS_CTL_SNAPSHOT_ENABLE		   (1 << 0)
 
 #define GEN7_TS_STRG_VAL		       0x7e04
@@ -297,330 +310,6 @@
 #define GEN7_EU_ATT_CLR_1	       0x8834
 #define GEN7_EU_RDATA		       0x8840
 
-#define GEN7_3D(Pipeline,Opcode,Subopcode) ((3 << 29) | \
-					   ((Pipeline) << 27) | \
-					   ((Opcode) << 24) | \
-					   ((Subopcode) << 16))
-
-#define GEN7_STATE_BASE_ADDRESS			GEN7_3D(0, 1, 1)
-#define GEN7_STATE_SIP				GEN7_3D(0, 1, 2)
-
-#define GEN7_PIPELINE_SELECT			GEN7_3D(1, 1, 4)
-
-#define GEN7_MEDIA_STATE_POINTERS		GEN7_3D(2, 0, 0)
-#define GEN7_MEDIA_OBJECT			GEN7_3D(2, 1, 0)
-
-#define GEN7_3DSTATE_BINDING_TABLE_POINTERS	GEN7_3D(3, 0, 1)
-# define GEN7_3DSTATE_BINDING_TABLE_MODIFY_PS  (1 << 12)/* for GEN7 */
-# define GEN7_3DSTATE_BINDING_TABLE_MODIFY_GS  (1 << 9) /* for GEN7 */
-# define GEN7_3DSTATE_BINDING_TABLE_MODIFY_VS  (1 << 8) /* for GEN7 */
-
-#define GEN7_3DSTATE_VERTEX_BUFFERS		GEN7_3D(3, 0, 8)
-#define GEN7_3DSTATE_VERTEX_ELEMENTS		GEN7_3D(3, 0, 9)
-#define GEN7_3DSTATE_INDEX_BUFFER		GEN7_3D(3, 0, 0xa)
-#define GEN7_3DSTATE_VF_STATISTICS		GEN7_3D(3, 0, 0xb)
-
-#define GEN7_3DSTATE_DRAWING_RECTANGLE		GEN7_3D(3, 1, 0)
-#define GEN7_3DSTATE_CONSTANT_COLOR		GEN7_3D(3, 1, 1)
-#define GEN7_3DSTATE_SAMPLER_PALETTE_LOAD	GEN7_3D(3, 1, 2)
-#define GEN7_3DSTATE_CHROMA_KEY			GEN7_3D(3, 1, 4)
-
-#define GEN7_3DSTATE_POLY_STIPPLE_OFFSET		GEN7_3D(3, 1, 6)
-#define GEN7_3DSTATE_POLY_STIPPLE_PATTERN	GEN7_3D(3, 1, 7)
-#define GEN7_3DSTATE_LINE_STIPPLE		GEN7_3D(3, 1, 8)
-#define GEN7_3DSTATE_GLOBAL_DEPTH_OFFSET_CLAMP	GEN7_3D(3, 1, 9)
-/* These two are BLC and CTG only, not BW or CL */
-#define GEN7_3DSTATE_AA_LINE_PARAMS		GEN7_3D(3, 1, 0xa)
-#define GEN7_3DSTATE_GS_SVB_INDEX		GEN7_3D(3, 1, 0xb)
-
-#define GEN7_PIPE_CONTROL			GEN7_3D(3, 2, 0)
-
-#define GEN7_3DPRIMITIVE				GEN7_3D(3, 3, 0)
-
-/* for GEN7+ */
-#define GEN7_3DSTATE_SAMPLER_STATE_POINTERS	GEN7_3D(3, 0, 0x02)
-# define GEN7_3DSTATE_SAMPLER_STATE_MODIFY_PS	(1 << 12)
-# define GEN7_3DSTATE_SAMPLER_STATE_MODIFY_GS	(1 << 9)
-# define GEN7_3DSTATE_SAMPLER_STATE_MODIFY_VS	(1 << 8)
-
-#define GEN7_3DSTATE_URB			GEN7_3D(3, 0, 0x05)
-/* DW1 */
-# define GEN7_3DSTATE_URB_VS_SIZE_SHIFT		16
-# define GEN7_3DSTATE_URB_VS_ENTRIES_SHIFT	0
-/* DW2 */
-# define GEN7_3DSTATE_URB_GS_ENTRIES_SHIFT	8
-# define GEN7_3DSTATE_URB_GS_SIZE_SHIFT		0
-
-#define GEN7_3DSTATE_VIEWPORT_STATE_POINTERS	GEN7_3D(3, 0, 0x0d)
-# define GEN7_3DSTATE_VIEWPORT_STATE_MODIFY_CC		(1 << 12)
-# define GEN7_3DSTATE_VIEWPORT_STATE_MODIFY_SF		(1 << 11)
-# define GEN7_3DSTATE_VIEWPORT_STATE_MODIFY_CLIP	(1 << 10)
-
-#define GEN7_3DSTATE_CC_STATE_POINTERS		GEN7_3D(3, 0, 0x0e)
-
-#define GEN7_3DSTATE_VS				GEN7_3D(3, 0, 0x10)
-
-#define GEN7_3DSTATE_GS				GEN7_3D(3, 0, 0x11)
-/* DW4 */
-# define GEN7_3DSTATE_GS_DISPATCH_START_GRF_SHIFT	0
-
-#define GEN7_3DSTATE_CLIP			GEN7_3D(3, 0, 0x12)
-
-#define GEN7_3DSTATE_SF				GEN7_3D(3, 0, 0x13)
-/* DW1 */
-# define GEN7_3DSTATE_SF_NUM_OUTPUTS_SHIFT		22
-# define GEN7_3DSTATE_SF_URB_ENTRY_READ_LENGTH_SHIFT	11
-# define GEN7_3DSTATE_SF_URB_ENTRY_READ_OFFSET_SHIFT	4
-/* DW2 */
-/* DW3 */
-# define GEN7_3DSTATE_SF_CULL_BOTH			(0 << 29)
-# define GEN7_3DSTATE_SF_CULL_NONE			(1 << 29)
-# define GEN7_3DSTATE_SF_CULL_FRONT			(2 << 29)
-# define GEN7_3DSTATE_SF_CULL_BACK			(3 << 29)
-/* DW4 */
-# define GEN7_3DSTATE_SF_TRI_PROVOKE_SHIFT		29
-# define GEN7_3DSTATE_SF_LINE_PROVOKE_SHIFT		27
-# define GEN7_3DSTATE_SF_TRIFAN_PROVOKE_SHIFT		25
-
-
-#define GEN7_3DSTATE_WM				GEN7_3D(3, 0, 0x14)
-/* DW2 */
-# define GEN7_3DSTATE_WM_SAMPLER_COUNT_SHITF			27
-# define GEN7_3DSTATE_WM_BINDING_TABLE_ENTRY_COUNT_SHIFT	18
-/* DW4 */
-# define GEN7_3DSTATE_WM_DISPATCH_START_GRF_0_SHIFT		16
-/* DW5 */
-# define GEN7_3DSTATE_WM_MAX_THREADS_SHIFT			25
-# define GEN7_3DSTATE_WM_DISPATCH_ENABLE			(1 << 19)
-# define GEN7_3DSTATE_WM_16_DISPATCH_ENABLE			(1 << 1)
-# define GEN7_3DSTATE_WM_8_DISPATCH_ENABLE			(1 << 0)
-/* DW6 */
-# define GEN7_3DSTATE_WM_NUM_SF_OUTPUTS_SHIFT			20
-# define GEN7_3DSTATE_WM_NONPERSPECTIVE_SAMPLE_BARYCENTRIC	(1 << 15)
-# define GEN7_3DSTATE_WM_NONPERSPECTIVE_CENTROID_BARYCENTRIC	(1 << 14)
-# define GEN7_3DSTATE_WM_NONPERSPECTIVE_PIXEL_BARYCENTRIC	(1 << 13)
-# define GEN7_3DSTATE_WM_PERSPECTIVE_SAMPLE_BARYCENTRIC		(1 << 12)
-# define GEN7_3DSTATE_WM_PERSPECTIVE_CENTROID_BARYCENTRIC	(1 << 11)
-# define GEN7_3DSTATE_WM_PERSPECTIVE_PIXEL_BARYCENTRIC		(1 << 10)
-
-
-#define GEN7_3DSTATE_CONSTANT_VS		GEN7_3D(3, 0, 0x15)
-#define GEN7_3DSTATE_CONSTANT_GS          	GEN7_3D(3, 0, 0x16)
-#define GEN7_3DSTATE_CONSTANT_PS          	GEN7_3D(3, 0, 0x17)
-
-#define GEN7_3DSTATE_SAMPLE_MASK		GEN7_3D(3, 0, 0x18)
-
-#define GEN7_3DSTATE_MULTISAMPLE		GEN7_3D(3, 1, 0x0d)
-/* DW1 */
-# define GEN7_3DSTATE_MULTISAMPLE_PIXEL_LOCATION_CENTER		(0 << 4)
-# define GEN7_3DSTATE_MULTISAMPLE_PIXEL_LOCATION_UPPER_LEFT	(1 << 4)
-# define GEN7_3DSTATE_MULTISAMPLE_NUMSAMPLES_1			(0 << 1)
-# define GEN7_3DSTATE_MULTISAMPLE_NUMSAMPLES_4			(2 << 1)
-# define GEN7_3DSTATE_MULTISAMPLE_NUMSAMPLES_8			(3 << 1)
-
-#define PIPELINE_SELECT_3D		0
-#define PIPELINE_SELECT_MEDIA		1
-
-#define UF0_CS_REALLOC			(1 << 13)
-#define UF0_VFE_REALLOC			(1 << 12)
-#define UF0_SF_REALLOC			(1 << 11)
-#define UF0_CLIP_REALLOC		(1 << 10)
-#define UF0_GS_REALLOC			(1 << 9)
-#define UF0_VS_REALLOC			(1 << 8)
-#define UF1_CLIP_FENCE_SHIFT		20
-#define UF1_GS_FENCE_SHIFT		10
-#define UF1_VS_FENCE_SHIFT		0
-#define UF2_CS_FENCE_SHIFT		20
-#define UF2_VFE_FENCE_SHIFT		10
-#define UF2_SF_FENCE_SHIFT		0
-
-/* for GEN7_STATE_BASE_ADDRESS */
-#define BASE_ADDRESS_MODIFY		(1 << 0)
-
-/* for GEN7_3DSTATE_PIPELINED_POINTERS */
-#define GEN7_GS_DISABLE		       0
-#define GEN7_GS_ENABLE		       1
-#define GEN7_CLIP_DISABLE	       0
-#define GEN7_CLIP_ENABLE		       1
-
-/* for GEN7_PIPE_CONTROL */
-#define GEN7_PIPE_CONTROL_NOWRITE       (0 << 14)
-#define GEN7_PIPE_CONTROL_WRITE_QWORD   (1 << 14)
-#define GEN7_PIPE_CONTROL_WRITE_DEPTH   (2 << 14)
-#define GEN7_PIPE_CONTROL_WRITE_TIME    (3 << 14)
-#define GEN7_PIPE_CONTROL_DEPTH_STALL   (1 << 13)
-#define GEN7_PIPE_CONTROL_WC_FLUSH      (1 << 12)
-#define GEN7_PIPE_CONTROL_IS_FLUSH      (1 << 11)
-#define GEN7_PIPE_CONTROL_TC_FLUSH      (1 << 10)
-#define GEN7_PIPE_CONTROL_NOTIFY_ENABLE (1 << 8)
-#define GEN7_PIPE_CONTROL_GLOBAL_GTT    (1 << 2)
-#define GEN7_PIPE_CONTROL_LOCAL_PGTT    (0 << 2)
-#define GEN7_PIPE_CONTROL_DEPTH_CACHE_FLUSH	(1 << 0)
-
-/* 3DPRIMITIVE bits */
-#define GEN7_3DPRIMITIVE_VERTEX_SEQUENTIAL (0 << 15)
-#define GEN7_3DPRIMITIVE_VERTEX_RANDOM	  (1 << 15)
-/* Primitive types are in gen7_defines.h */
-#define GEN7_3DPRIMITIVE_TOPOLOGY_SHIFT	  10
-
-#define GEN7_SVG_CTL		       0x7400
-
-#define GEN7_SVG_CTL_GS_BA	       (0 << 8)
-#define GEN7_SVG_CTL_SS_BA	       (1 << 8)
-#define GEN7_SVG_CTL_IO_BA	       (2 << 8)
-#define GEN7_SVG_CTL_GS_AUB	       (3 << 8)
-#define GEN7_SVG_CTL_IO_AUB	       (4 << 8)
-#define GEN7_SVG_CTL_SIP		       (5 << 8)
-
-#define GEN7_SVG_RDATA		       0x7404
-#define GEN7_SVG_WORK_CTL	       0x7408
-
-#define GEN7_VF_CTL		       0x7500
-
-#define GEN7_VF_CTL_SNAPSHOT_COMPLETE		   (1 << 31)
-#define GEN7_VF_CTL_SNAPSHOT_MUX_SELECT_THREADID	   (0 << 8)
-#define GEN7_VF_CTL_SNAPSHOT_MUX_SELECT_VF_DEBUG	   (1 << 8)
-#define GEN7_VF_CTL_SNAPSHOT_TYPE_VERTEX_SEQUENCE   (0 << 4)
-#define GEN7_VF_CTL_SNAPSHOT_TYPE_VERTEX_INDEX	   (1 << 4)
-#define GEN7_VF_CTL_SKIP_INITIAL_PRIMITIVES	   (1 << 3)
-#define GEN7_VF_CTL_MAX_PRIMITIVES_LIMIT_ENABLE	   (1 << 2)
-#define GEN7_VF_CTL_VERTEX_RANGE_LIMIT_ENABLE	   (1 << 1)
-#define GEN7_VF_CTL_SNAPSHOT_ENABLE	     	   (1 << 0)
-
-#define GEN7_VF_STRG_VAL		       0x7504
-#define GEN7_VF_STR_VL_OVR	       0x7508
-#define GEN7_VF_VC_OVR		       0x750c
-#define GEN7_VF_STR_PSKIP	       0x7510
-#define GEN7_VF_MAX_PRIM		       0x7514
-#define GEN7_VF_RDATA		       0x7518
-
-#define GEN7_VS_CTL		       0x7600
-#define GEN7_VS_CTL_SNAPSHOT_COMPLETE		   (1 << 31)
-#define GEN7_VS_CTL_SNAPSHOT_MUX_VERTEX_0	   (0 << 8)
-#define GEN7_VS_CTL_SNAPSHOT_MUX_VERTEX_1	   (1 << 8)
-#define GEN7_VS_CTL_SNAPSHOT_MUX_VALID_COUNT	   (2 << 8)
-#define GEN7_VS_CTL_SNAPSHOT_MUX_VS_KERNEL_POINTER  (3 << 8)
-#define GEN7_VS_CTL_SNAPSHOT_ALL_THREADS		   (1 << 2)
-#define GEN7_VS_CTL_THREAD_SNAPSHOT_ENABLE	   (1 << 1)
-#define GEN7_VS_CTL_SNAPSHOT_ENABLE		   (1 << 0)
-
-#define GEN7_VS_STRG_VAL		       0x7604
-#define GEN7_VS_RDATA		       0x7608
-
-#define GEN7_SF_CTL		       0x7b00
-#define GEN7_SF_CTL_SNAPSHOT_COMPLETE		   (1 << 31)
-#define GEN7_SF_CTL_SNAPSHOT_MUX_VERTEX_0_FF_ID	   (0 << 8)
-#define GEN7_SF_CTL_SNAPSHOT_MUX_VERTEX_0_REL_COUNT (1 << 8)
-#define GEN7_SF_CTL_SNAPSHOT_MUX_VERTEX_1_FF_ID	   (2 << 8)
-#define GEN7_SF_CTL_SNAPSHOT_MUX_VERTEX_1_REL_COUNT (3 << 8)
-#define GEN7_SF_CTL_SNAPSHOT_MUX_VERTEX_2_FF_ID	   (4 << 8)
-#define GEN7_SF_CTL_SNAPSHOT_MUX_VERTEX_2_REL_COUNT (5 << 8)
-#define GEN7_SF_CTL_SNAPSHOT_MUX_VERTEX_COUNT	   (6 << 8)
-#define GEN7_SF_CTL_SNAPSHOT_MUX_SF_KERNEL_POINTER  (7 << 8)
-#define GEN7_SF_CTL_MIN_MAX_PRIMITIVE_RANGE_ENABLE  (1 << 4)
-#define GEN7_SF_CTL_DEBUG_CLIP_RECTANGLE_ENABLE	   (1 << 3)
-#define GEN7_SF_CTL_SNAPSHOT_ALL_THREADS		   (1 << 2)
-#define GEN7_SF_CTL_THREAD_SNAPSHOT_ENABLE	   (1 << 1)
-#define GEN7_SF_CTL_SNAPSHOT_ENABLE		   (1 << 0)
-
-#define GEN7_SF_STRG_VAL		       0x7b04
-#define GEN7_SF_RDATA		       0x7b18
-
-#define GEN7_WIZ_CTL		       0x7c00
-#define GEN7_WIZ_CTL_SNAPSHOT_COMPLETE		   (1 << 31)
-#define GEN7_WIZ_CTL_SUBSPAN_INSTANCE_SHIFT	   16
-#define GEN7_WIZ_CTL_SNAPSHOT_MUX_WIZ_KERNEL_POINTER   (0 << 8)
-#define GEN7_WIZ_CTL_SNAPSHOT_MUX_SUBSPAN_INSTANCE     (1 << 8)
-#define GEN7_WIZ_CTL_SNAPSHOT_MUX_PRIMITIVE_SEQUENCE   (2 << 8)
-#define GEN7_WIZ_CTL_SINGLE_SUBSPAN_DISPATCH	      (1 << 6)
-#define GEN7_WIZ_CTL_IGNORE_COLOR_SCOREBOARD_STALLS    (1 << 5)
-#define GEN7_WIZ_CTL_ENABLE_SUBSPAN_INSTANCE_COMPARE   (1 << 4)
-#define GEN7_WIZ_CTL_USE_UPSTREAM_SNAPSHOT_FLAG	      (1 << 3)
-#define GEN7_WIZ_CTL_SNAPSHOT_ALL_THREADS	      (1 << 2)
-#define GEN7_WIZ_CTL_THREAD_SNAPSHOT_ENABLE	      (1 << 1)
-#define GEN7_WIZ_CTL_SNAPSHOT_ENABLE		      (1 << 0)
-
-#define GEN7_WIZ_STRG_VAL			      0x7c04
-#define GEN7_WIZ_RDATA				      0x7c18
-
-#define GEN7_TS_CTL		       0x7e00
-#define GEN7_TS_CTL_SNAPSHOT_COMPLETE		   (1 << 31)
-#define GEN7_TS_CTL_SNAPSHOT_MESSAGE_ERROR	   (0 << 8)
-#define GEN7_TS_CTL_SNAPSHOT_INTERFACE_DESCRIPTOR   (3 << 8)
-#define GEN7_TS_CTL_SNAPSHOT_ALL_CHILD_THREADS	   (1 << 2)
-#define GEN7_TS_CTL_SNAPSHOT_ALL_ROOT_THREADS  	   (1 << 1)
-#define GEN7_TS_CTL_SNAPSHOT_ENABLE		   (1 << 0)
-
-#define GEN7_TS_STRG_VAL		       0x7e04
-#define GEN7_TS_RDATA		       0x7e08
-
-#define GEN7_TD_CTL		       0x8000
-#define GEN7_TD_CTL_MUX_SHIFT	       8
-#define GEN7_TD_CTL_EXTERNAL_HALT_R0_DEBUG_MATCH	   (1 << 7)
-#define GEN7_TD_CTL_FORCE_EXTERNAL_HALT		   (1 << 6)
-#define GEN7_TD_CTL_EXCEPTION_MASK_OVERRIDE	   (1 << 5)
-#define GEN7_TD_CTL_FORCE_THREAD_BREAKPOINT_ENABLE  (1 << 4)
-#define GEN7_TD_CTL_BREAKPOINT_ENABLE		   (1 << 2)
-#define GEN7_TD_CTL2		       0x8004
-#define GEN7_TD_CTL2_ILLEGAL_OPCODE_EXCEPTION_OVERRIDE (1 << 28)
-#define GEN7_TD_CTL2_MASKSTACK_EXCEPTION_OVERRIDE      (1 << 26)
-#define GEN7_TD_CTL2_SOFTWARE_EXCEPTION_OVERRIDE	      (1 << 25)
-#define GEN7_TD_CTL2_ACTIVE_THREAD_LIMIT_SHIFT	      16
-#define GEN7_TD_CTL2_ACTIVE_THREAD_LIMIT_ENABLE	      (1 << 8)
-#define GEN7_TD_CTL2_THREAD_SPAWNER_EXECUTION_MASK_ENABLE (1 << 7)
-#define GEN7_TD_CTL2_WIZ_EXECUTION_MASK_ENABLE	      (1 << 6)
-#define GEN7_TD_CTL2_SF_EXECUTION_MASK_ENABLE	      (1 << 5)
-#define GEN7_TD_CTL2_CLIPPER_EXECUTION_MASK_ENABLE     (1 << 4)
-#define GEN7_TD_CTL2_GS_EXECUTION_MASK_ENABLE	      (1 << 3)
-#define GEN7_TD_CTL2_VS_EXECUTION_MASK_ENABLE	      (1 << 0)
-#define GEN7_TD_VF_VS_EMSK	       0x8008
-#define GEN7_TD_GS_EMSK		       0x800c
-#define GEN7_TD_CLIP_EMSK	       0x8010
-#define GEN7_TD_SF_EMSK		       0x8014
-#define GEN7_TD_WIZ_EMSK		       0x8018
-#define GEN7_TD_0_6_EHTRG_VAL	       0x801c
-#define GEN7_TD_0_7_EHTRG_VAL	       0x8020
-#define GEN7_TD_0_6_EHTRG_MSK           0x8024
-#define GEN7_TD_0_7_EHTRG_MSK	       0x8028
-#define GEN7_TD_RDATA		       0x802c
-#define GEN7_TD_TS_EMSK		       0x8030
-
-#define GEN7_EU_CTL		       0x8800
-#define GEN7_EU_CTL_SELECT_SHIFT	       16
-#define GEN7_EU_CTL_DATA_MUX_SHIFT      8
-#define GEN7_EU_ATT_0		       0x8810
-#define GEN7_EU_ATT_1		       0x8814
-#define GEN7_EU_ATT_DATA_0	       0x8820
-#define GEN7_EU_ATT_DATA_1	       0x8824
-#define GEN7_EU_ATT_CLR_0	       0x8830
-#define GEN7_EU_ATT_CLR_1	       0x8834
-#define GEN7_EU_RDATA		       0x8840
-
-/* 3D state:
- */
-#define _3DOP_3DSTATE_PIPELINED       0x0
-#define _3DOP_3DSTATE_NONPIPELINED    0x1
-#define _3DOP_3DCONTROL               0x2
-#define _3DOP_3DPRIMITIVE             0x3
-
-#define _3DSTATE_PIPELINED_POINTERS       0x00
-#define _3DSTATE_BINDING_TABLE_POINTERS   0x01
-#define _3DSTATE_VERTEX_BUFFERS           0x08
-#define _3DSTATE_VERTEX_ELEMENTS          0x09
-#define _3DSTATE_INDEX_BUFFER             0x0A
-#define _3DSTATE_VF_STATISTICS            0x0B
-#define _3DSTATE_DRAWING_RECTANGLE            0x00
-#define _3DSTATE_CONSTANT_COLOR               0x01
-#define _3DSTATE_SAMPLER_PALETTE_LOAD         0x02
-#define _3DSTATE_CHROMA_KEY                   0x04
-#define _3DSTATE_DEPTH_BUFFER                 0x05
-#define _3DSTATE_POLY_STIPPLE_OFFSET          0x06
-#define _3DSTATE_POLY_STIPPLE_PATTERN         0x07
-#define _3DSTATE_LINE_STIPPLE                 0x08
-#define _3DSTATE_GLOBAL_DEPTH_OFFSET_CLAMP    0x09
-#define _3DCONTROL    0x00
-#define _3DPRIMITIVE  0x00
-
 #define _3DPRIM_POINTLIST         0x01
 #define _3DPRIM_LINELIST          0x02
 #define _3DPRIM_LINESTRIP         0x03
@@ -646,13 +335,13 @@
 #define _3DPRIM_VERTEXBUFFER_ACCESS_SEQUENTIAL 0
 #define _3DPRIM_VERTEXBUFFER_ACCESS_RANDOM     1
 
-#define GEN7_ANISORATIO_2     0 
-#define GEN7_ANISORATIO_4     1 
-#define GEN7_ANISORATIO_6     2 
-#define GEN7_ANISORATIO_8     3 
-#define GEN7_ANISORATIO_10    4 
-#define GEN7_ANISORATIO_12    5 
-#define GEN7_ANISORATIO_14    6 
+#define GEN7_ANISORATIO_2     0
+#define GEN7_ANISORATIO_4     1
+#define GEN7_ANISORATIO_6     2
+#define GEN7_ANISORATIO_8     3
+#define GEN7_ANISORATIO_10    4
+#define GEN7_ANISORATIO_12    5
+#define GEN7_ANISORATIO_14    6
 #define GEN7_ANISORATIO_16    7
 
 #define GEN7_BLENDFACTOR_ONE                 0x1
@@ -751,20 +440,20 @@
 #define GEN7_LOGICOPFUNCTION_COPY             12
 #define GEN7_LOGICOPFUNCTION_OR_REVERSE       13
 #define GEN7_LOGICOPFUNCTION_OR               14
-#define GEN7_LOGICOPFUNCTION_SET              15  
+#define GEN7_LOGICOPFUNCTION_SET              15
 
-#define GEN7_MAPFILTER_NEAREST        0x0 
-#define GEN7_MAPFILTER_LINEAR         0x1 
+#define GEN7_MAPFILTER_NEAREST        0x0
+#define GEN7_MAPFILTER_LINEAR         0x1
 #define GEN7_MAPFILTER_ANISOTROPIC    0x2
 
-#define GEN7_MIPFILTER_NONE        0   
-#define GEN7_MIPFILTER_NEAREST     1   
+#define GEN7_MIPFILTER_NONE        0
+#define GEN7_MIPFILTER_NEAREST     1
 #define GEN7_MIPFILTER_LINEAR      3
 
 #define GEN7_POLYGON_FRONT_FACING     0
 #define GEN7_POLYGON_BACK_FACING      1
 
-#define GEN7_PREFILTER_ALWAYS     0x0 
+#define GEN7_PREFILTER_ALWAYS     0x0
 #define GEN7_PREFILTER_NEVER      0x1
 #define GEN7_PREFILTER_LESS       0x2
 #define GEN7_PREFILTER_EQUAL      0x3
@@ -774,10 +463,10 @@
 #define GEN7_PREFILTER_GEQUAL     0x7
 
 #define GEN7_PROVOKING_VERTEX_0    0
-#define GEN7_PROVOKING_VERTEX_1    1 
+#define GEN7_PROVOKING_VERTEX_1    1
 #define GEN7_PROVOKING_VERTEX_2    2
 
-#define GEN7_RASTRULE_UPPER_LEFT  0    
+#define GEN7_RASTRULE_UPPER_LEFT  0
 #define GEN7_RASTRULE_UPPER_RIGHT 1
 
 #define GEN7_RENDERTARGET_CLAMPRANGE_UNORM    0
@@ -993,7 +682,6 @@
 #define GEN7_VFCOMPONENT_STORE_PID    7
 
 
-
 /* Execution Unit (EU) defines
  */
 
@@ -1136,7 +824,7 @@
 
 #define GEN7_ARF_NULL                  0x00
 #define GEN7_ARF_ADDRESS               0x10
-#define GEN7_ARF_ACCUMULATOR           0x20   
+#define GEN7_ARF_ACCUMULATOR           0x20
 #define GEN7_ARF_FLAG                  0x30
 #define GEN7_ARF_MASK                  0x40
 #define GEN7_ARF_MASK_STACK            0x50
@@ -1151,8 +839,6 @@
 #define GEN7_LMASK   2
 #define GEN7_CMASK   3
 
-
-
 #define GEN7_THREAD_NORMAL     0
 #define GEN7_THREAD_ATOMIC     1
 #define GEN7_THREAD_SWITCH     2
@@ -1536,29 +1222,31 @@ struct gen7_sampler_state {
 	} ss3;
 };
 
-
 /* Surface state DW0 */
-#define GEN7_SURFACE_CUBEFACE_ENABLES	0x3f
-#define GEN7_SURFACE_RC_READ_WRITE	(1 << 7)
-#define GEN7_SURFACE_TILED		(1<< 12)
-#define GEN7_SURFACE_TILED_Y		(1<< 13)
+#define GEN7_SURFACE_RC_READ_WRITE	(1 << 8)
+#define GEN7_SURFACE_TILED		(1 << 14)
+#define GEN7_SURFACE_TILED_Y		(1 << 13)
 #define GEN7_SURFACE_FORMAT_SHIFT	18
-#define GEN7_SURFACE_FORMAT_MASK	INTEL_MASK(26, 18)
-#define GEN7_SURFACE_TYPE_SHIFT		28
+#define GEN7_SURFACE_TYPE_SHIFT		29
 
 /* Surface state DW2 */
-#define GEN7_SURFACE_HEIGHT_SHIFT        19
-#define GEN7_SURFACE_HEIGHT_MASK         INTEL_MASK(31, 19)
-#define GEN7_SURFACE_WIDTH_SHIFT         6
-#define GEN7_SURFACE_WIDTH_MASK          INTEL_MASK(18, 6)
-#define GEN7_SURFACE_LOD_SHIFT           2
-#define GEN7_SURFACE_LOD_MASK            INTEL_MASK(5, 2)
+#define GEN7_SURFACE_HEIGHT_SHIFT        16
+#define GEN7_SURFACE_WIDTH_SHIFT         0
 
 /* Surface state DW3 */
 #define GEN7_SURFACE_DEPTH_SHIFT         21
-#define GEN7_SURFACE_DEPTH_MASK          INTEL_MASK(31, GEN7_SURFACE_DEPTH_SHIFT)
 #define GEN7_SURFACE_PITCH_SHIFT         0
-#define GEN7_SURFACE_PITCH_MASK          INTEL_MASK(18, GEN7_SURFACE_PITCH_SHIFT)
+
+#define HSW_SWIZZLE_ZERO		0
+#define HSW_SWIZZLE_ONE			1
+#define HSW_SWIZZLE_RED			4
+#define HSW_SWIZZLE_GREEN		5
+#define HSW_SWIZZLE_BLUE		6
+#define HSW_SWIZZLE_ALPHA		7
+#define __HSW_SURFACE_SWIZZLE(r,g,b,a) \
+	((a) << 16 | (b) << 19 | (g) << 22 | (r) << 25)
+#define HSW_SURFACE_SWIZZLE(r,g,b,a) \
+	__HSW_SURFACE_SWIZZLE(HSW_SWIZZLE_##r, HSW_SWIZZLE_##g, HSW_SWIZZLE_##b, HSW_SWIZZLE_##a)
 
 /* _3DSTATE_VERTEX_BUFFERS on GEN7*/
 /* DW1 */
@@ -1569,48 +1257,6 @@ struct gen7_sampler_state {
 # define GEN7_3DPRIM_VERTEXBUFFER_ACCESS_SEQUENTIAL     (0 << 8)
 # define GEN7_3DPRIM_VERTEXBUFFER_ACCESS_RANDOM         (1 << 8)
 
-/* 3DSTATE_WM on GEN7 */
-/* DW1 */
-# define GEN7_WM_STATISTICS_ENABLE                              (1 << 31)
-# define GEN7_WM_DEPTH_CLEAR                                    (1 << 30)
-# define GEN7_WM_DISPATCH_ENABLE                                (1 << 29)
-# define GEN6_WM_DEPTH_RESOLVE                                  (1 << 28)
-# define GEN7_WM_HIERARCHICAL_DEPTH_RESOLVE                     (1 << 27)
-# define GEN7_WM_KILL_ENABLE                                    (1 << 25)
-# define GEN7_WM_PSCDEPTH_OFF                                   (0 << 23)
-# define GEN7_WM_PSCDEPTH_ON                                    (1 << 23)
-# define GEN7_WM_PSCDEPTH_ON_GE                                 (2 << 23)
-# define GEN7_WM_PSCDEPTH_ON_LE                                 (3 << 23)
-# define GEN7_WM_USES_SOURCE_DEPTH                              (1 << 20)
-# define GEN7_WM_USES_SOURCE_W                                  (1 << 19)
-# define GEN7_WM_POSITION_ZW_PIXEL                              (0 << 17)
-# define GEN7_WM_POSITION_ZW_CENTROID                           (2 << 17)
-# define GEN7_WM_POSITION_ZW_SAMPLE                             (3 << 17)
-# define GEN7_WM_NONPERSPECTIVE_SAMPLE_BARYCENTRIC              (1 << 16)
-# define GEN7_WM_NONPERSPECTIVE_CENTROID_BARYCENTRIC            (1 << 15)
-# define GEN7_WM_NONPERSPECTIVE_PIXEL_BARYCENTRIC               (1 << 14)
-# define GEN7_WM_PERSPECTIVE_SAMPLE_BARYCENTRIC                 (1 << 13)
-# define GEN7_WM_PERSPECTIVE_CENTROID_BARYCENTRIC               (1 << 12)
-# define GEN7_WM_PERSPECTIVE_PIXEL_BARYCENTRIC                  (1 << 11)
-# define GEN7_WM_USES_INPUT_COVERAGE_MASK                       (1 << 10)
-# define GEN7_WM_LINE_END_CAP_AA_WIDTH_0_5                      (0 << 8)
-# define GEN7_WM_LINE_END_CAP_AA_WIDTH_1_0                      (1 << 8)
-# define GEN7_WM_LINE_END_CAP_AA_WIDTH_2_0                      (2 << 8)
-# define GEN7_WM_LINE_END_CAP_AA_WIDTH_4_0                      (3 << 8)
-# define GEN7_WM_LINE_AA_WIDTH_0_5                              (0 << 6)
-# define GEN7_WM_LINE_AA_WIDTH_1_0                              (1 << 6)
-# define GEN7_WM_LINE_AA_WIDTH_2_0                              (2 << 6)
-# define GEN7_WM_LINE_AA_WIDTH_4_0                              (3 << 6)
-# define GEN7_WM_POLYGON_STIPPLE_ENABLE                         (1 << 4)
-# define GEN7_WM_LINE_STIPPLE_ENABLE                            (1 << 3)
-# define GEN7_WM_POINT_RASTRULE_UPPER_RIGHT                     (1 << 2)
-# define GEN7_WM_MSRAST_OFF_PIXEL                               (0 << 0)
-# define GEN7_WM_MSRAST_OFF_PATTERN                             (1 << 0)
-# define GEN7_WM_MSRAST_ON_PIXEL                                (2 << 0)
-# define GEN7_WM_MSRAST_ON_PATTERN                              (3 << 0)
-/* DW2 */
-# define GEN7_WM_MSDISPMODE_PERPIXEL                            (1 << 31)
-
 #define GEN7_3DSTATE_CLEAR_PARAMS               GEN7_3D(3, 0, 0x04)
 #define GEN7_3DSTATE_DEPTH_BUFFER               GEN7_3D(3, 0, 0x05)
 # define GEN7_3DSTATE_DEPTH_BUFFER_TYPE_SHIFT	29
@@ -1646,7 +1292,9 @@ struct gen7_sampler_state {
 # define GEN7_PS_FLOATING_POINT_MODE_ALT                (1 << 16)
 /* DW3: scratch space */
 /* DW4 */
-# define GEN7_PS_MAX_THREADS_SHIFT                      24
+# define IVB_PS_MAX_THREADS_SHIFT                      24
+# define HSW_PS_MAX_THREADS_SHIFT                      23
+# define HSW_PS_SAMPLE_MASK_SHIFT                      12
 # define GEN7_PS_PUSH_CONSTANT_ENABLE                   (1 << 11)
 # define GEN7_PS_ATTRIBUTE_ENABLE                       (1 << 10)
 # define GEN7_PS_OMASK_TO_RENDER_TARGET                 (1 << 9)
